#[test]Expand description
Test attribute to ignore tests if CUDA isn’t available. Supports both sync and async tests (using tokio).
Must be named test to work with frameworks like rstest.
#[test]Test attribute to ignore tests if CUDA isn’t available. Supports both sync and async tests (using tokio).
Must be named test to work with frameworks like rstest.